/*
 * Copyright (C) 2022  Aravinth Manivannan <realaravinth@batsense.net>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
use std::collections::HashMap;

use serde::{Deserialize, Serialize};

#[derive(Deserialize, Serialize, Debug)]
#[serde(untagged)]
pub enum FormDType {
    Num(f64),
    Str(String),
}

impl FormDType {
    pub fn apply_types(&mut self) {
        if let Self::Str(data) = self {
            if let Ok(num) = data.parse::<f64>() {
                *self = Self::Num(num);
            }
        }
    }
}

pub type FormValue = HashMap<String, FormDType>;

#[derive(Serialize, Deserialize, Clone, Debug)]
pub struct Table {
    pub host: String,
    pub path: String,
}

#[derive(Serialize, Deserialize, Clone, Debug, Default)]
pub struct FormSubmissionResp {
    pub value: Option<serde_json::Value>,
    pub time: i64,
    pub id: usize,
}
